<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_Router.php,v 1.16 2007/06/24 10:44:50 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ܾ󥯥饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_Router.php,v 1.16 2007/06/24 10:44:50 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_Router
{
    /**
     * ǥեȥե̾
     * Ƭʸ
     *
     * @access protected
     * @var string
     */
    var $action_file_default = 'Index.php';
    /**
     * URLγĥ
     *
     * @access protected
     * @var string
     */
    var $url_ext = SYL_ROUTER_URL_EXT;
    /**
     * ¹ԥեγĥ
     *
     * @access protected
     * @var string
     */
    var $exe_ext = '.php';
    /**
     * ե
     *
     * @access protected
     * @var string
     */
    var $action_file = '';
    /**
     * ᥽å̾
     *
     * @access protected
     * @var string
     */
    var $action_method = '';
    /**
     * 饹̾
     *
     * @access protected
     * @var string
     */
    var $action_class = '';

    /**
     * 󥹥ȥ饯
     *
     * @access public
     * @param string 
     */
    function SyL_Router()
    {
    }

    /**
     * ܾ󥪥֥Ȥ
     *
     * @static
     * @access public
     * @param object ꥯȥ֥
     * @param string ܾ󥪥֥̾
     * @return object ܾ󥪥֥
     */
    function &factory(&$data, $rule)
    {
        $classname = 'SyL_Router' . ucfirst($rule);
        include_once SYL_INCLUDE_DIR . "/framework/Router/{$classname}.php";
        $router =& new $classname();
        $router->createActionInfo($data);
        return $router;
    }

    /**
     * ܾ󥪥֥ȤΥץѥƥ
     *
     * $this->action_method
     * $this->action_file
     * $this->action_class
     *
     * @access protected
     * @param object ꥯȥ֥
     */
    function createActionInfo(&$data)
    {
    }

    /**
     * ᥽å̾
     *
     * @access public
     * @return string ̾
     */
    function getActionName()
    {
        return $this->action_method;
    }

    /**
     * ե
     *
     * @access public
     * @return string ե
     */
    function getActionFile()
    {
        return $this->action_file;
    }

    /**
     * 饹̾
     *
     * @access public
     * @return string 饹ե
     */
    function getClassName()
    {
        return $this->action_class;
    }

}

?>
